@@ -7,14 +7,14 @@
 
 #include "pindialog.h"
 
-#include <QDesktopWidget>
 #include <QIcon>
 #include <QIntValidator>
+#include <QScreen>
 
 #include <KLocalizedString>
 #include <KWindowSystem>
 
-#include <ModemManagerQt/manager.h>
+#include <ModemManagerQt/Manager>
 
 PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *parent)
     : QDialog(parent)
@@ -36,7 +36,7 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
 
     ui = new Ui::PinWidget();
     ui->setupUi(this);
-    ui->pin->setPasswordMode(true);
+    ui->pin->setEchoMode(QLineEdit::Password);
 
     auto validator = new QIntValidator(this);
     validator->setRange(1000, 99999999);
@@ -48,7 +48,8 @@ PinDialog::PinDialog(ModemManager::Modem *modem, const Type type, QWidget *paren
     ui->puk->setValidator(validator2);
 
     ui->errorMessage->setHidden(true);
-    QRect desktop = QApplication::desktop()->screenGeometry(topLevelWidget());
+    const QRect desktop = screen()->availableGeometry();
+    // QRect desktop = QApplication::desktop()->screenGeometry(topLevelWidget());
     setMinimumWidth(360); // width of the PinePhone display
 
     pixmapLabel = new QLabel(this);
@@ -144,9 +145,9 @@ PinDialog::~PinDialog()
 
 void PinDialog::chkShowPassToggled(bool on)
 {
-    ui->pin->setPasswordMode(!on);
-    ui->pin2->setPasswordMode(!on);
-    ui->puk->setPasswordMode(!on);
+    ui->pin->setEchoMode(!on ? QLineEdit::Password : QLineEdit::Normal);
+    ui->pin2->setEchoMode(!on ? QLineEdit::Password : QLineEdit::Normal);
+    ui->puk->setEchoMode(!on ? QLineEdit::Password : QLineEdit::Normal);
 
     ui->puk->setCursorPosition(0);
     ui->pin->setCursorPosition(0);
