@@ -25,13 +25,15 @@
 #include <KLocalizedString>
 
 #if WITH_MODEMMANAGER_SUPPORT
-#include <ModemManagerQt/manager.h>
-#include <ModemManagerQt/modem.h>
-#include <ModemManagerQt/modem3gpp.h>
-#include <ModemManagerQt/modemcdma.h>
-#include <ModemManagerQt/modemdevice.h>
+#include <ModemManagerQt/Manager>
+#include <ModemManagerQt/Modem3Gpp>
+#include <ModemManagerQt/Modem>
+#include <ModemManagerQt/ModemCdma>
+#include <ModemManagerQt/ModemDevice>
 #endif
 
+#include <QStringBuilder>
+
 NetworkModelItem::NetworkModelItem(QObject *parent)
     : QObject(parent)
     , m_connectionState(NetworkManager::ActiveConnection::Deactivated)
@@ -595,6 +597,11 @@ void NetworkModelItem::updateDetails() const
             if (m_connectionState == NetworkManager::ActiveConnection::Activated) {
                 m_details << i18n("Connection speed") << UiUtils::connectionSpeed(wirelessDevice->bitRate());
             }
+            const NetworkManager::AccessPoint::Ptr accessPoint = wirelessDevice->findAccessPoint(m_specificPath);
+            if (accessPoint) {
+                m_details << i18n("Frequency") << UiUtils::wirelessFrequencyToString(accessPoint->frequency());
+                m_details << i18n("BSSID") << accessPoint->hardwareAddress();
+            }
             m_details << i18n("MAC Address") << wirelessDevice->permanentHardwareAddress();
         }
     } else if (m_type == NetworkManager::ConnectionSettings::Gsm || m_type == NetworkManager::ConnectionSettings::Cdma) {
